@@ -5,6 +5,8 @@ import (
 	"fmt"
 	"strings"
 
+	"github.com/onsi/ginkgo"
+
 	"github.com/fatedier/frp/pkg/transport"
 	"github.com/fatedier/frp/test/e2e/framework"
 	"github.com/fatedier/frp/test/e2e/framework/consts"
@@ -12,18 +14,16 @@ import (
 	"github.com/fatedier/frp/test/e2e/mock/server/streamserver"
 	"github.com/fatedier/frp/test/e2e/pkg/port"
 	"github.com/fatedier/frp/test/e2e/pkg/request"
-
-	. "github.com/onsi/ginkgo"
 )
 
-var _ = Describe("[Feature: Basic]", func() {
+var _ = ginkgo.Describe("[Feature: Basic]", func() {
 	f := framework.NewDefaultFramework()
 
-	Describe("TCP && UDP", func() {
+	ginkgo.Describe("TCP && UDP", func() {
 		types := []string{"tcp", "udp"}
 		for _, t := range types {
 			proxyType := t
-			It(fmt.Sprintf("Expose a %s echo server", strings.ToUpper(proxyType)), func() {
+			ginkgo.It(fmt.Sprintf("Expose a %s echo server", strings.ToUpper(proxyType)), func() {
 				serverConf := consts.DefaultServerConfig
 				clientConf := consts.DefaultClientConfig
 
@@ -93,8 +93,8 @@ var _ = Describe("[Feature: Basic]", func() {
 		}
 	})
 
-	Describe("HTTP", func() {
-		It("proxy to HTTP server", func() {
+	ginkgo.Describe("HTTP", func() {
+		ginkgo.It("proxy to HTTP server", func() {
 			serverConf := consts.DefaultServerConfig
 			vhostHTTPPort := f.AllocPort()
 			serverConf += fmt.Sprintf(`
@@ -175,8 +175,8 @@ var _ = Describe("[Feature: Basic]", func() {
 		})
 	})
 
-	Describe("HTTPS", func() {
-		It("proxy to HTTPS server", func() {
+	ginkgo.Describe("HTTPS", func() {
+		ginkgo.It("proxy to HTTPS server", func() {
 			serverConf := consts.DefaultServerConfig
 			vhostHTTPSPort := f.AllocPort()
 			serverConf += fmt.Sprintf(`
@@ -237,7 +237,7 @@ var _ = Describe("[Feature: Basic]", func() {
 			framework.ExpectNoError(err)
 			localServer := httpserver.New(
 				httpserver.WithBindPort(localPort),
-				httpserver.WithTlsConfig(tlsConfig),
+				httpserver.WithTLSConfig(tlsConfig),
 				httpserver.WithResponse([]byte("test")),
 			)
 			f.RunServer("", localServer)
@@ -275,11 +275,11 @@ var _ = Describe("[Feature: Basic]", func() {
 		})
 	})
 
-	Describe("STCP && SUDP", func() {
+	ginkgo.Describe("STCP && SUDP", func() {
 		types := []string{"stcp", "sudp"}
 		for _, t := range types {
 			proxyType := t
-			It(fmt.Sprintf("Expose echo server with %s", strings.ToUpper(proxyType)), func() {
+			ginkgo.It(fmt.Sprintf("Expose echo server with %s", strings.ToUpper(proxyType)), func() {
 				serverConf := consts.DefaultServerConfig
 				clientServerConf := consts.DefaultClientConfig
 				clientVisitorConf := consts.DefaultClientConfig
@@ -381,8 +381,8 @@ var _ = Describe("[Feature: Basic]", func() {
 		}
 	})
 
-	Describe("TCPMUX", func() {
-		It("Type tcpmux", func() {
+	ginkgo.Describe("TCPMUX", func() {
+		ginkgo.It("Type tcpmux", func() {
 			serverConf := consts.DefaultServerConfig
 			clientConf := consts.DefaultClientConfig
 
